<?php
namespace Ep\TecDoc\Middleware;

use Dflydev\FigCookies\Cookies;
use Dflydev\FigCookies\SetCookie;
use Dflydev\FigCookies\SetCookies;
use Ep\Middleware\BaseUrl;
use Ep\TecDoc\TecDocInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Zend\Session\Container as SessionContainer;

/**
 * Class SelectedVehicle
 *
 * @package Ep\TecDoc\Middleware
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class SelectedVehicle implements MiddlewareInterface
{
    /** @var TecDocInterface */
    protected $tecdoc;
    /** @var SessionContainer */
    protected $session;

    /**
     * SelectedVehicle constructor.
     *
     * @param TecDocInterface $tecdoc
     * @param SessionContainer $session
     */
    public function __construct(TecDocInterface $tecdoc)
    {
        $this->tecdoc = $tecdoc;
    }

    /**
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        $uri = $request->getUri();
        $cookies = Cookies::fromRequest($request);

        if (preg_match('#(/[a-z0-9-]+--[a-z0-9_-]+-\d+--[a-z0-9-]+-(\d+))(/|$)#', $uri->getPath(), $matches)) {
            $this->tecdoc->setCurrentVehicle(intval($matches[2]));

            $request = $request->withUri(
                $uri->withPath(
                    substr($uri->getPath(), strlen($matches[1]))
                )
            );
        } else if ($cookies->has('_tv')) {
            $this->tecdoc->setCurrentVehicle($cookies->get('_tv')->getValue());
        } else if ($cookies->has('_tecdoc2')) {
            $this->tecdoc->setCurrentVehicle($cookies->get('_tecdoc2')->getValue());
        }

        $response = $handler->handle($request);

        if (($vehicle = $this->tecdoc->getCurrentVehicle())) {
            $response = SetCookies::fromResponse($response)
                ->with(
                    SetCookie::createRememberedForever('_tv', $vehicle->getId())
                         ->withPath('/')
                )
                ->renderIntoSetCookieHeader($response);
        }

        return $response;
    }
}