<?php
namespace Ep\TecDoc\Middleware;

use Ep\Middleware\BaseUrl;
use Ep\TecDoc\TecDoc;
use Ep\Wp\WordPress;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Zend\Stratigility\MiddlewarePipe;
use Zend\Stratigility\MiddlewarePipeInterface;
use function Zend\Stratigility\path;

class TecDocMiddleware implements MiddlewarePipeInterface
{
    /** @var MiddlewarePipeInterface */
    protected $pipeline;
    /** @var WordPress */
    protected $wp;

    /**
     * TecDocMiddleware constructor.
     *
     * @param TecDoc $tecdoc
     */
    public function __construct(ContainerInterface $container)
    {
        $this->pipeline = new MiddlewarePipe();

        if ($container->has('wp')) {
            $this->wp = $container->get('wp');
        }

        $this->pipeline->pipe(path('/vehicle-select', new VehicleSelect($container)));
    }

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if ($this->wp) {
            $this->wp->init($request->getAttribute(BaseUrl::BASE_URL), $request);
        }

        return $this->pipeline->process($request, $handler);
    }

    public function pipe(MiddlewareInterface $middleware): void
    {
        $this->pipeline->pipe($middleware);
    }

    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        if ($this->wp) {
            $this->wp->init($request->getAttribute(BaseUrl::BASE_URL));
        }

        return $this->pipeline->handle($request);
    }
}