<?php
namespace Ep\TecDoc\Record\Traits;

use DatePeriod;
use DateTime;

/**
 * Class ConstructionPeriodTrait
 *
 * @package Ep\TecDoc\Record\Traits
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
trait ConstructionPeriodTrait
{
    /** @var DateTime */
    protected $constructionPeriodStart;
    /** @var DateTime */
    protected $constructionPeriodEnd;
    /** @var DatePeriod */
    protected $constructionPeriod;

    /**
     * @return DateTime
     */
    protected function getConstructionPeriodStart(): DateTime
    {
        if (null === $this->constructionPeriodStart) {
            $this->constructionPeriodStart = $this->parseDate($this->yearOfConstrFrom);
        }

        return $this->constructionPeriodStart;
    }

    /**
     * @return DateTime
     */
    protected function getConstructionPeriodEnd(): DateTime
    {
        if (null === $this->constructionPeriodEnd) {
            $this->constructionPeriodEnd = $this->parseDate($this->yearOfConstrFrom);
        }

        return $this->constructionPeriodEnd;
    }

    /**
     * @param int $date
     *
     * @return bool|DateTime
     */
    protected function parseDate(?int $date)
    {
        if (!$date) {
            $date = date('Ymd000000');
        } else {
            $date .= '01000000';
        }

        return DateTime::createFromFormat('YmdHis', $date);
    }

    /**
     * @return int
     */
    public function getConstructionPeriod(): DatePeriod
    {
        if (null === $this->constructionPeriod) {
            $start = $this->getConstructionPeriodStart();
            $end = $this->getConstructionPeriodEnd();
            $interval = $end->diff($start);

            $this->constructionPeriod = new DatePeriod($start, $interval, $end);
        }

        return $this->constructionPeriod;
    }
}