<?php
namespace Ep\TecDoc\Request;

use Ep\TecDoc\Response\VehicleIdsByCriteriaResponse;

class VehicleIdsByCriteriaRequest extends AbstractRequest
{
    /** @var string */
    protected $responseClass = VehicleIdsByCriteriaResponse::class;
    /** @var string */
    protected $remoteFunctionName = 'getVehicleIdsByCriteria';

    /** @var int */
    protected $axisConfigurationId;

    /** @var int */
    protected $constructionTypeId;

    use Parts\CountryGroupFlagTrait;

    /** @var int */
    protected $cylinderCapacityFrom;

    /** @var int */
    protected $cylinderCapacityTo;

    use Parts\FavouredListTrait;

    /** @var int */
    protected  $fuelTypeId;

    use Parts\LangTrait;

    use Parts\ManuIdTrait;

    use Parts\CarTypeTrait;

    use Parts\CountriesCarSelectionTrait;

    /** @var int */
    protected $modId;

    /** @var string */
    protected $modelDescription;

    /** @var int */
    protected  $powerFrom;

    /** @var bool */
    protected  $powerHpType;

    /** @var int */
    protected  $powerTo;

    /** @var int */
    protected $tonnageFrom;

    /** @var int */
    protected $tonnageTo;

    /** @var int */
    protected $yearOfConstruction;


    //GETERI I SETERI


    /**
     * @return int
     */
    public function getAxisConfigurationId(): int
    {
        return $this->axisConfigurationId;
    }

    /**
     * @param int $axisConfigurationId
     */
    public function setAxisConfigurationId(int $axisConfigurationId): void
    {
        $this->axisConfigurationId = $axisConfigurationId;
    }

    /**
     * @return int
     */
    public function getConstructionTypeId(): int
    {
        return $this->constructionTypeId;
    }

    /**
     * @param int $constructionTypeId
     */
    public function setConstructionTypeId(int $constructionTypeId): void
    {
        $this->constructionTypeId = $constructionTypeId;
    }

    /**
     * @return int
     */
    public function getCylinderCapacityFrom(): int
    {
        return $this->cylinderCapacityFrom;
    }

    /**
     * @param int $cylinderCapacityFrom
     */
    public function setCylinderCapacityFrom(int $cylinderCapacityFrom): void
    {
        $this->cylinderCapacityFrom = $cylinderCapacityFrom;
    }

    /**
     * @return int
     */
    public function getCylinderCapacityTo(): int
    {
        return $this->cylinderCapacityTo;
    }

    /**
     * @param int $cylinderCapacityTo
     */
    public function setCylinderCapacityTo(int $cylinderCapacityTo): void
    {
        $this->cylinderCapacityTo = $cylinderCapacityTo;
    }

    /**
     * @return int
     */
    public function getFuelTypeId(): int
    {
        return $this->fuelTypeId;
    }

    /**
     * @param int $fuelTypeId
     */
    public function setFuelTypeId(int $fuelTypeId): void
    {
        $this->fuelTypeId = $fuelTypeId;
    }

    /**
     * @return int
     */
    public function getModId(): int
    {
        return $this->modId;
    }

    /**
     * @param int $modId
     */
    public function setModId(int $modId): void
    {
        $this->modId = $modId;
    }

    /**
     * @return string
     */
    public function getModelDescription(): string
    {
        return $this->modelDescription;
    }

    /**
     * @param string $modelDescription
     */
    public function setModelDescription(string $modelDescription): void
    {
        $this->modelDescription = $modelDescription;
    }

    /**
     * @return int
     */
    public function getPowerFrom(): int
    {
        return $this->powerFrom;
    }

    /**
     * @param int $powerFrom
     */
    public function setPowerFrom(int $powerFrom): void
    {
        $this->powerFrom = $powerFrom;
    }

    /**
     * @return bool
     */
    public function isPowerHpType(): bool
    {
        return $this->powerHpType;
    }

    /**
     * @param bool $powerHpType
     */
    public function setPowerHpType(bool $powerHpType): void
    {
        $this->powerHpType = $powerHpType;
    }

    /**
     * @return int
     */
    public function getPowerTo(): int
    {
        return $this->powerTo;
    }

    /**
     * @param int $powerTo
     */
    public function setPowerTo(int $powerTo): void
    {
        $this->powerTo = $powerTo;
    }

    /**
     * @return int
     */
    public function getTonnageFrom(): int
    {
        return $this->tonnageFrom;
    }

    /**
     * @param int $tonnageFrom
     */
    public function setTonnageFrom(int $tonnageFrom): void
    {
        $this->tonnageFrom = $tonnageFrom;
    }

    /**
     * @return int
     */
    public function getTonnageTo(): int
    {
        return $this->tonnageTo;
    }

    /**
     * @param int $tonnageTo
     */
    public function setTonnageTo(int $tonnageTo): void
    {
        $this->tonnageTo = $tonnageTo;
    }

    /**
     * @return int
     */
    public function getYearOfConstruction(): int
    {
        return $this->yearOfConstruction;
    }

    /**
     * @param int $yearOfConstruction
     */
    public function setYearOfConstruction(int $yearOfConstruction): void
    {
        if ($numlength = strlen((string)$yearOfConstruction) != 4)
        {
            throw new \InvalidArgumentException('Godina mora biti integer u formatu:YYYY');
        }
        $this->yearOfConstruction = $yearOfConstruction;
    }



    public function toJson()
    {
        $params = [
            'getVehicleIdsByCriteria' => [
                'carType' => $this->carType,
                'countriesCarSelection' => $this->countriesCarSelection,
                'countryGroupFlag' => $this->countryGroupFlag,
                'lang' => $this->lang,
                'provider' => $this->provider
            ],
        ];

        $optional = array(
            'axisConfigurationId',
            'constructionTypeId',
            'cylinderCapacityFrom',
            'cylinderCapacityTo',
            'favouredList',
            'fuelTypeId',
            'manuId',
            'modId',
            'modelDescription',
            'powerFrom',
            'powerHpType',
            'powerTo',
            'tonnageFrom',
            'tonnageTo',
            'yearOfConstruction',
        );

        foreach ($optional as $argName)
        {
            if (null !== $this->$argName) {
                $params['getVehicleIdsByCriteria'][$argName] = $this->$argName;
            }
        }

        return json_encode($params);
    }
}