<?php
namespace Ep\TecDoc;

use Ep\Cache\AbstractCacheFactory;
use Ep\Http\AbstractHttpClientFactory;
use Interop\Container\ContainerInterface;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class TecDocServiceFactory
 *
 * @package Ep\TecDoc
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class TecDocServiceFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return object
     *
     * @throws \Exception
     */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
	    $app = $container->get('config')['app'] ?? [];
        $config = $container->get('config')['tecdoc'] ?? [];

        $cacheFactory = new AbstractCacheFactory();
        $httpFactory = new AbstractHttpClientFactory();

        $httpConfig = [
		    'base_uri' => TecDocService::SERVICE_URI,
            'timeout' => $config['http_timeout'] ?? 2,
            'headers' => [
                'Content-Type' => 'application/json',
            ],
        ];

        if (($app['development'] ?? false) === false) {
            $cache = $cacheFactory($container, '', [
                'adapter' => 'filesystem',
                'options' => [
                    'namespace' => 'tecdoc',
                ],
            ]);
            $httpConfig['cache'] = $cache;
        } else {
            $cache = $cacheFactory($container, '', ['adapter' => 'null']);
        }

        $client = $httpFactory($container, '', $httpConfig);

        $attributesTable = $config['save_attribute_names']
            ? $container->get('tecdoc.attributesTable')
            : null;

		return new TecDocService($config, $client, $cache, $attributesTable);
	}
}