<?php
namespace Ep\TecDoc\View\Helper;

use Ep\TecDoc\Record\ModelSeriesRecord;
use Ep\TecDoc\Record\VehicleByIdRecord;
use Zend\View\Helper\AbstractHelper;

/**
 * Class ModelName
 *
 * @package Ep\TecDoc\View\Helper
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class ModelName extends AbstractHelper
{
    /** @var ConstructionYear */
    protected $constructionYear;

    /**
     * @return ConstructionYear
     */
    public function getConstructionYear(): ConstructionYear
    {
        if (null === $this->constructionYear) {
            $this->constructionYear = method_exists($this->view, 'plugin')
                ? $this->view->plugin('tecdoc_construction_year')
                : new ConstructionYear();
        }

        return $this->constructionYear;
    }

    public function __invoke($model)
    {
        if ($model instanceof VehicleByIdRecord) {
            return $this->getModelNameFromVehicle($model);
        }

        $constructionYear = $this->getConstructionYear();
        return sprintf('%s %s', $model->getName(), $constructionYear($model->getConstructionPeriod()));
    }

    protected function getModelNameFromVehicle(VehicleByIdRecord $vehicle)
    {
        $constructionYear = $this->getConstructionYear();
        return sprintf('%s %s', $vehicle->getModelName(), $constructionYear($vehicle->getConstructionPeriod()));
    }
}